==> moodle-1.5-mysql.tgz: moodle/lang/sk/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.6 development (2005052400)


$string['about'] = 'O tomto editore';
$string['absbottom'] = 'plne dolu (Absbottom)';
$string['address'] = 'Adresa';
$string['alertnoselectedtext'] = 'Najprv muste oznai text';
$string['alignment'] = 'Zarovnanie';
$string['alternatetext'] = 'Alternatvny text';
$string['anchorhelp'] = 'Tmto vytvorte iba nvestie. Odkaz sem vak muste nadefinova rune.';
$string['anchorname'] = 'Nzov nvestia';
$string['anchors'] = 'Nvestia';
$string['baseline'] = 'Zkladn (Baseline)';
$string['bold'] = 'Tun';
$string['borderthickness'] = 'Hrbka ohranienia';
$string['bottom'] = 'Dolu (Bottom)';
$string['browse'] = 'Prehadva';
$string['cancel'] = 'Zrui';
$string['cellpadding'] = 'Vntorn okraj buniek';
$string['cellspacing'] = 'Vzdialenos medzi bunkami';
$string['choosechar'] = 'Vyberte znak';
$string['chooseicon'] = 'Vyberte si ikonu na vloenie';
$string['close'] = 'Zatvori';
$string['closeafterreplace'] = 'Zatvori po nahraden';
$string['cols'] = 'Stpce';
$string['copy'] = 'Koprova vber';
$string['createanchor'] = 'Vytvori nvestie';
$string['createfolder'] = 'Vytvori prieinok';
$string['createlink'] = 'Vloi odkaz ';
$string['cut'] = 'Vybra vber';
$string['cutpastemozilla'] = 'Bohuia, pre vloenie textu zo schrnky momentlne nemete poui ben klvesov skratku i tlaidlo Vloi. Toto sprvanie je spsoben bezpenostnm opatrenm zabudovanm do niektorch verzi prehliadaov Mozilla a Firefox.<br /><br />Existuj spsoby, ako sa d toto sprvanie obs, take vyskajte:<br />(1) Miesto CTRL+v skste skratku SHIFT+Insert<br />(2) Pouite ponuku pravy->Vloi v menu vho prehliadaa<br />(3) Upravte si nastavenie vho prehliadaa v sbore user.js<br />(4) Na Linuxe skste vloi text pomocou nastavenho tlaidla myi<br /><br />Pre viac informci kliknite na tlaidlo OK, pre nvrat do editora stlate Cancel, Storno i Zrui.';
$string['delete'] = 'Vymaza';
$string['filebrowser'] = 'Prehliada sborov';
$string['findwhat'] = 'Hada';
$string['fontname'] = 'Nzov fontu';
$string['fontsize'] = 'Vekos fontu';
$string['forecolor'] = 'Farba fontu';
$string['formatblock'] = 'Formt';
$string['fullscreen'] = 'Na cel obrazovku';
$string['heading'] = 'Nadpis';
$string['height'] = 'Vka';
$string['hilitecolor'] = 'Farba pozadia';
$string['horizontal'] = 'Vodorovn';
$string['horizontalrule'] = 'Vodorovn iara';
$string['htmlmode'] = 'Prepn na HTML zdroj';
$string['imageurl'] = 'URL adresa obrzku';
$string['indent'] = 'Zvi odsadenie';
$string['insertchar'] = 'Vloi pecilny znak';
$string['insertimage'] = 'Vloi obrzok';
$string['insertlink'] = 'Vloi odkaz';
$string['insertsmile'] = 'Vloi smajlka';
$string['inserttable'] = 'Vloi tabuku';
$string['italic'] = 'Kurzva';
$string['itemsreplaced'] = 'poloiek nahradench!';
$string['justifycenter'] = 'Zarovna na stred';
$string['justifyfull'] = 'Zarovna do bloku';
$string['justifyleft'] = 'Zarovna doava';
$string['justifyright'] = 'Zarovna doprava';
$string['layout'] = 'Vzhad';
$string['left'] = 'Naavo';
$string['lefttoright'] = 'Zava doprava';
$string['linkproperties'] = 'Vlastnosti odkazu';
$string['linktarget'] = 'Kde otvori';
$string['linktargetblank'] = 'Nov okno';
$string['linktargetnone'] = 'iadny';
$string['linktargetother'] = 'In (zatia nefunguje)';
$string['linktargetself'] = 'V tom istom rmci';
$string['linktargettop'] = 'V tom istom okne';
$string['linktitle'] = 'Nadpis';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'Citliv na vekos';
$string['middle'] = 'Uprostred (Middle)';
$string['minimize'] = 'Minimalizova editor';
$string['move'] = 'Presun';
$string['nolink'] = 'Neprepja na slovnk';
$string['normal'] = 'Normlny';
$string['notimage'] = 'Vybran sbor nie je obrzok. Prosm, vyberte si in sbor!';
$string['notset'] = 'Nenastaven';
$string['ok'] = 'OK';
$string['options'] = 'Monosti';
$string['orderedlist'] = 'slovan zoznam';
$string['outdent'] = 'Zmeni odsadenie';
$string['paste'] = 'Vloi zo schrnky';
$string['path'] = 'HTML cesta';
$string['percent'] = 'Percent';
$string['pixels'] = 'Pixelov';
$string['popupeditor'] = 'Zvi editor';
$string['preformatted'] = 'Predformtovan';
$string['preview'] = 'Nhad';
$string['properties'] = 'Vlastnosti';
$string['redo'] = 'Opakova posledn akciu';
$string['regularexpressions'] = 'Poui \'regular expression\'';
$string['removelink'] = 'Odstrni odkaz';
$string['rename'] = 'Premenova';
$string['replaceall'] = 'Nahradi vetko';
$string['replacewith'] = 'Nahradi';
$string['right'] = 'Vpravo';
$string['righttoleft'] = 'Sprava doava';
$string['rows'] = 'Riadkov';
$string['searchandreplace'] = 'Vyhadaj a nahra';
$string['searchnotfound'] = 'Hadan reazec nebol njden!';
$string['selectcolor'] = 'Vber farby';
$string['selection'] = 'Vber';
$string['showhelp'] = 'Npoveda k pouvaniu editora';
$string['size'] = 'Vekos';
$string['spacing'] = 'Vzdialenos od textu';
$string['strikethrough'] = 'Prekrtn';
$string['subscript'] = 'Doln index';
$string['superscript'] = 'Horn index';
$string['textindicator'] = 'Aktulny tl';
$string['textmode'] = 'Ste v TEXTOVOM reime. Pouite [<>]tlaidlo na nvrat do reimu WYSIWYG.';
$string['texttop'] = 'Text hore (texttop)';
$string['top'] = 'Hore (top)';
$string['type'] = 'Typ';
$string['underline'] = 'Podiarknu';
$string['undo'] = 'Vrti posledn akciu (UNDO)';
$string['unorderedlist'] = 'Zoznam odrok';
$string['upload'] = 'Nata';
$string['vertical'] = 'Zvisle';
$string['width'] = 'rka';
$string['wordclean'] = 'Vyisti HTML z Wordu';
$string['zip'] = 'Zozipova';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/sk/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.6 development (2005060201)


$string['about'] = 'O tomto editore';
$string['absbottom'] = 'plne dolu (Absbottom)';
$string['address'] = 'Adresa';
$string['alertnoselectedtext'] = 'Najprv muste oznai text!';
$string['alignment'] = 'Zarovnanie';
$string['alternatetext'] = 'Alternatvny text';
$string['anchorhelp'] = 'Tmto vytvorte iba nvestie. Odkaz sem vak muste nadefinova rune.';
$string['anchorname'] = 'Nzov nvestia';
$string['anchors'] = 'Nvestia';
$string['baseline'] = 'Zklad (Baseline)';
$string['bold'] = 'Tun';
$string['borderthickness'] = 'Hrbka ohranienia';
$string['bottom'] = 'Dolu (Bottom)';
$string['browse'] = 'Prehadva';
$string['cancel'] = 'Zrui';
$string['cellpadding'] = 'Vntorn okraj buniek';
$string['cellspacing'] = 'Vzdialenos medzi bunkami';
$string['choosechar'] = 'Vyberte znak';
$string['chooseicon'] = 'Vyberte si ikonu na vloenie';
$string['close'] = 'Zatvori';
$string['closeafterreplace'] = 'Zatvori po nahraden';
$string['cols'] = 'Stpce';
$string['copy'] = 'Koprova vber';
$string['createanchor'] = 'Vytvori nvestie';
$string['createfolder'] = 'Vytvori prieinok';
$string['createlink'] = 'Vloi odkaz ';
$string['cut'] = 'Vybra vber';
$string['cutpastemozilla'] = 'Bohuia, pre vloenie textu zo schrnky momentlne nemete poui ben klvesov skratku i tlaidlo Vloi. Toto sprvanie je spsoben bezpenostnm opatrenm zabudovanm do niektorch verzi prehliadaov Mozilla a Firefox.<br /><br />Existuj spsoby, ako sa d toto sprvanie obs, skste  vyska toto:<br />(1) Miesto CTRL+v skste skratku SHIFT+Insert<br />(2) Pouite ponuku pravy->Vloi v menu Vho prehliadaa<br />(3) Upravte si nastavenie Vho prehliadaa v sbore user.js<br /><br />Pre viac informci kliknite na tlaidlo OK, pre nvrat do editora stlate Cancel, Storno i Zrui.';
$string['delete'] = 'Odstrni';
$string['filebrowser'] = 'Prehliada sborov';
$string['findwhat'] = 'Njs';
$string['fontname'] = 'Nzov fontu';
$string['fontsize'] = 'Vekos fontu';
$string['forecolor'] = 'Farba fontu';
$string['formatblock'] = 'Formt';
$string['fullscreen'] = 'Na cel obrazovku';
$string['heading'] = 'Nadpis';
$string['height'] = 'Vka';
$string['hilitecolor'] = 'Farba pozadia';
$string['horizontal'] = 'Vodorovn';
$string['horizontalrule'] = 'Vodorovn iara';
$string['htmlmode'] = 'Prepn na HTML zdroj';
$string['imageurl'] = 'URL obrzku';
$string['indent'] = 'Zvi odsadenie';
$string['insertchar'] = 'Vloi pecilny znak';
$string['insertimage'] = 'Vloi obrzok';
$string['insertlink'] = 'Vloi odkaz';
$string['insertsmile'] = 'Vloi smajlka';
$string['inserttable'] = 'Vloi tabuku';
$string['italic'] = 'Kurzva';
$string['itemsreplaced'] = 'poloiek nahradench!';
$string['justifycenter'] = 'Zarovna na stred';
$string['justifyfull'] = 'Zarovna do bloku';
$string['justifyleft'] = 'Zarovna doava';
$string['justifyright'] = 'Zarovna doprava';
$string['layout'] = 'Vzhad';
$string['left'] = 'Naavo';
$string['lefttoright'] = 'Zava doprava';
$string['linkproperties'] = 'Vlastnosti odkazu';
$string['linktarget'] = 'Kde otvori';
$string['linktargetblank'] = 'V novom okne';
$string['linktargetnone'] = 'Bez urenia';
$string['linktargetother'] = 'Inde (zatia nefunguje)';
$string['linktargetself'] = 'V tom istom rmci';
$string['linktargettop'] = 'V tom istom okne';
$string['linktitle'] = 'Nadpis';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'Citliv na vekos psma';
$string['middle'] = 'Uprostred (Middle)';
$string['minimize'] = 'Minimalizova editor';
$string['move'] = 'Presun';
$string['nolink'] = 'Zabrni automatickmu vytvraniu odkazov';
$string['normal'] = 'Normlny';
$string['notimage'] = 'Vybran sbor nie je obrzok. Prosm, vyberte si in sbor!';
$string['notset'] = 'Nenastaven';
$string['ok'] = 'OK';
$string['options'] = 'Monosti';
$string['orderedlist'] = 'slovan zoznam';
$string['outdent'] = 'Zmeni odsadenie';
$string['paste'] = 'Vloi zo schrnky';
$string['path'] = 'HTML cesta';
$string['percent'] = 'Percent';
$string['pixels'] = 'Pixelov';
$string['popupeditor'] = 'Zvi editor';
$string['preformatted'] = 'Predformtovan';
$string['preview'] = 'Nhad';
$string['properties'] = 'Vlastnosti';
$string['redo'] = 'Opakova posledn innos';
$string['regularexpressions'] = 'Poui regulrne vrazy';
$string['removelink'] = 'Odstrni odkaz';
$string['rename'] = 'Premenova';
$string['replaceall'] = 'Nahradi vetko';
$string['replacewith'] = 'Nahradi';
$string['right'] = 'Vpravo';
$string['righttoleft'] = 'Sprava doava';
$string['rows'] = 'Riadkov';
$string['searchandreplace'] = 'Vyhadaj a nahra';
$string['searchnotfound'] = 'Hadan reazec nebol njden!';
$string['selectcolor'] = 'Vber farby';
$string['selection'] = 'Vber';
$string['showhelp'] = 'Npoveda k pouvaniu editora';
$string['size'] = 'Vekos';
$string['spacing'] = 'Vzdialenos od textu';
$string['strikethrough'] = 'Prekrtn';
$string['subscript'] = 'Doln index';
$string['superscript'] = 'Horn index';
$string['textindicator'] = 'Aktulny tl';
$string['textmode'] = 'Ste v TEXTOVOM reime. Pouite [<>]tlaidlo na nvrat do reimu WYSIWYG.';
$string['texttop'] = 'Text hore (texttop)';
$string['top'] = 'Hore (top)';
$string['type'] = 'Typ';
$string['underline'] = 'Podiarknu';
$string['undo'] = 'Vrti posledn innos (UNDO)';
$string['unorderedlist'] = 'Zoznam odrok';
$string['upload'] = 'Prenies';
$string['vertical'] = 'Zvisle';
$string['width'] = 'rka';
$string['wordclean'] = 'Vyisti HTML z Wordu';
$string['zip'] = 'Zozipova';

?>
